@@ -18,14 +18,14 @@ import tim.prune.function.DiskCacheConfig;
 import tim.prune.function.DownloadOsmFunction;
 import tim.prune.function.DuplicatePoint;
 import tim.prune.function.FindWaypoint;
-import tim.prune.function.ProjectPoint;
-import tim.prune.function.ShowFullDetails;
 import tim.prune.function.GetWikipediaFunction;
 import tim.prune.function.HelpScreen;
 import tim.prune.function.IgnoreExifThumb;
 import tim.prune.function.InterpolateFunction;
 import tim.prune.function.PhotoPopupFunction;
 import tim.prune.function.PlayAudioFunction;
+import tim.prune.function.ProjectCircle;
+import tim.prune.function.ProjectPoint;
 import tim.prune.function.RearrangePhotosFunction;
 import tim.prune.function.RearrangeWaypointsFunction;
 import tim.prune.function.RemoveAudioFunction;
@@ -35,6 +35,7 @@ import tim.prune.function.SearchOsmPoisFunction;
 import tim.prune.function.SearchWikipediaNames;
 import tim.prune.function.SelectSegmentFunction;
 import tim.prune.function.SelectTimezoneFunction;
+import tim.prune.function.ShowFullDetails;
 import tim.prune.function.ShowKeysScreen;
 import tim.prune.function.ShowThreeDFunction;
 import tim.prune.function.SingleNumericParameterFunction;
@@ -48,6 +49,7 @@ import tim.prune.function.compress.MarkPointsInRectangleFunction;
 import tim.prune.function.deletebydate.DeleteByDateFunction;
 import tim.prune.function.distance.DistanceFunction;
 import tim.prune.function.edit.PointNameEditor;
+import tim.prune.function.edit.TruncatePointCoords;
 import tim.prune.function.estimate.EstimateTime;
 import tim.prune.function.estimate.LearnParameters;
 import tim.prune.function.settings.SaveConfig;
@@ -86,6 +88,7 @@ public abstract class FunctionLibrary
 	public static GenericFunction FUNCTION_SAVECONFIG  = null;
 	public static GenericFunction FUNCTION_EDIT_WAYPOINT_NAME = null;
 	public static GenericFunction FUNCTION_PROJECT_POINT = null;
+	public static GenericFunction FUNCTION_PROJECT_CIRCLE = null;
 	public static GenericFunction FUNCTION_REARRANGE_WAYPOINTS = null;
 	public static GenericFunction FUNCTION_SELECT_SEGMENT = null;
 	public static GenericFunction FUNCTION_SPLIT_SEGMENTS = null;
@@ -110,6 +113,7 @@ public abstract class FunctionLibrary
 	public static GenericFunction FUNCTION_CONVERT_NAMES_TO_TIMES  = null;
 	public static GenericFunction FUNCTION_DELETE_FIELD_VALUES  = null;
 	public static GenericFunction FUNCTION_FIND_WAYPOINT = null;
+	public static GenericFunction FUNCTION_TRUNCATE_POINT_COORDS = null;
 	public static GenericFunction FUNCTION_DUPLICATE_POINT = null;
 	public static GenericFunction FUNCTION_CONNECT_TO_POINT = null;
 	public static GenericFunction FUNCTION_DISCONNECT_PHOTO = null;
@@ -163,6 +167,7 @@ public abstract class FunctionLibrary
 		FUNCTION_SAVECONFIG = new SaveConfig(inApp);
 		FUNCTION_EDIT_WAYPOINT_NAME = new PointNameEditor(inApp);
 		FUNCTION_PROJECT_POINT = new ProjectPoint(inApp);
+		FUNCTION_PROJECT_CIRCLE = new ProjectCircle(inApp);
 		FUNCTION_REARRANGE_WAYPOINTS = new RearrangeWaypointsFunction(inApp);
 		FUNCTION_SELECT_SEGMENT = new SelectSegmentFunction(inApp);
 		FUNCTION_SPLIT_SEGMENTS = new SplitSegmentsFunction(inApp);
@@ -187,6 +192,7 @@ public abstract class FunctionLibrary
 		FUNCTION_CONVERT_NAMES_TO_TIMES = new ConvertNamesToTimes(inApp);
 		FUNCTION_DELETE_FIELD_VALUES = new DeleteFieldValues(inApp);
 		FUNCTION_FIND_WAYPOINT = new FindWaypoint(inApp);
+		FUNCTION_TRUNCATE_POINT_COORDS = new TruncatePointCoords(inApp);
 		FUNCTION_DUPLICATE_POINT = new DuplicatePoint(inApp);
 		FUNCTION_CONNECT_TO_POINT = new ConnectToPointFunction(inApp);
 		FUNCTION_DISCONNECT_PHOTO = new DisconnectPhotoFunction(inApp);
