@@ -41,13 +41,14 @@ public class SetLanguage extends GenericFunction
 	private int _startIndex = 0;
 
 	/** Names of languages for display in dropdown (not translated) */
-	private static final String[] LANGUAGE_NAMES = {"afrikaans", "\u010de\u0161tina", "deutsch", "english", "american english",
-		"espa\u00F1ol", "fran\u00E7ais", "italiano", "magyar", "nederlands", "polski", "portugu\u00EAs", "rom\u00E2n\u0103",
-		"suomi", "svenska", "\u0440\u0443\u0441\u0441\u043a\u0438\u0439 (russian)", "\u4e2d\u6587 (chinese)",
+	private static final String[] LANGUAGE_NAMES = {"afrikaans", "catal\u00e0", "\u010de\u0161tina", "deutsch",
+		"english", "american english", "espa\u00F1ol", "fran\u00E7ais", "italiano", "magyar", "nederlands",
+		"polski", "portugu\u00EAs", "rom\u00E2n\u0103", "suomi", "svenska",
+		"\u0440\u0443\u0441\u0441\u043a\u0438\u0439 (russian)", "\u4e2d\u6587 (chinese)",
 		"\u65E5\u672C\u8A9E (japanese)", "\uD55C\uAD6D\uC5B4/\uC870\uC120\uB9D0 (korean)", "schwiizerd\u00FC\u00FCtsch"
 	};
 	/** Associated language codes (must be in same order as names!) */
-	private static final String[] LANGUAGE_CODES = {"af", "cz", "de", "en", "en_us", "es", "fr", "it", "hu",
+	private static final String[] LANGUAGE_CODES = {"af", "ca", "cz", "de", "en", "en_us", "es", "fr", "it", "hu",
 		"nl", "pl", "pt", "ro", "fi", "sv", "ru", "zh", "ja", "ko", "de_ch"
 	};
 
@@ -288,7 +289,7 @@ public class SetLanguage extends GenericFunction
 				if (currLine.trim().length() > 0 && currLine.matches("[a-z.]+=.+")) {
 					ok = true;
 				}
-				if (currLine.indexOf('\0', 0) >= 0) {
+				if (currLine.indexOf('\0') >= 0) {
 					wrong = true;
 				}
 				currLine = reader.readLine();
