@@ -89,7 +89,9 @@ public class MapCanvas extends JPanel implements MouseListener, MouseMotionListe
 	/** Current drawing mode */
 	private int _drawMode = MODE_DEFAULT;
 	/** Current waypoint icon definition */
-	WpIconDefinition _waypointIconDefinition = null;
+	private WpIconDefinition _waypointIconDefinition = null;
+	/** Remember whether map is being drawn with empty track or not */
+	private boolean _emptyTrack = true;
 
 	/** Constant for click sensitivity when selecting nearest point */
 	private static final int CLICK_SENSITIVITY = 10;
@@ -415,12 +417,12 @@ public class MapCanvas extends JPanel implements MouseListener, MouseMotionListe
 			}
 
 			// Recognise empty map position, if no data has been loaded
-			if (_mapPosition.isEmpty())
+			if (_emptyTrack && _track.getNumPoints() > 1)
 			{
-				// Set to some default area
 				zoomToFit();
 				_recalculate = true;
 			}
+			_emptyTrack = (_track.getNumPoints() == 0);
 
 			// Draw the map contents if necessary
 			if (_mapImage == null || _recalculate)
@@ -436,7 +438,16 @@ public class MapCanvas extends JPanel implements MouseListener, MouseMotionListe
 			switch (_drawMode)
 			{
 				case MODE_DRAG_POINT:
-					drawDragLines(inG, _selection.getCurrentPointIndex()-1, _selection.getCurrentPointIndex()+1);
+					DataPoint currPoint = _track.getPoint(_selection.getCurrentPointIndex());
+					if (currPoint != null)
+					{
+						if (currPoint.isWaypoint()) {
+							drawDragLines(inG, _selection.getCurrentPointIndex(), _selection.getCurrentPointIndex());
+						}
+						else {
+							drawDragLines(inG, _selection.getCurrentPointIndex()-1, _selection.getCurrentPointIndex()+1);
+						}
+					}
 					break;
 
 				case MODE_CREATE_MIDPOINT:
@@ -457,12 +468,15 @@ public class MapCanvas extends JPanel implements MouseListener, MouseMotionListe
 					break;
 
 				case MODE_DRAW_POINTS_CONT:
-					// draw line to mouse position to show drawing mode
-					inG.setColor(Config.getColourScheme().getColour(ColourScheme.IDX_POINT));
-					int prevIndex = _track.getNumPoints()-1;
-					int px = getWidth() / 2 + _mapPosition.getXFromCentre(_track.getX(prevIndex));
-					int py = getHeight() / 2 + _mapPosition.getYFromCentre(_track.getY(prevIndex));
-					inG.drawLine(px, py, _dragToX, _dragToY);
+					int prevIndex = _track.getNumPoints() - 1;
+					if (prevIndex >= 0)
+					{
+						// draw line to mouse position to show drawing mode
+						inG.setColor(Config.getColourScheme().getColour(ColourScheme.IDX_POINT));
+						int px = getWidth() / 2 + _mapPosition.getXFromCentre(_track.getX(prevIndex));
+						int py = getHeight() / 2 + _mapPosition.getYFromCentre(_track.getY(prevIndex));
+						inG.drawLine(px, py, _dragToX, _dragToY);
+					}
 					break;
 			}
 		}
@@ -563,7 +577,6 @@ public class MapCanvas extends JPanel implements MouseListener, MouseMotionListe
 			// init tile cacher
 			_tileManager.centreMap(_mapPosition.getZoom(), _mapPosition.getCentreTileX(), _mapPosition.getCentreTileY());
 
-			boolean loadingFailed = false;
 			if (_mapImage == null) return;
 
 			if (_tileManager.isOverzoomed())
@@ -578,7 +591,7 @@ public class MapCanvas extends JPanel implements MouseListener, MouseMotionListe
 				// Loop over tiles drawing each one
 				int[] tileIndices = _mapPosition.getTileIndices(getWidth(), getHeight());
 				int[] pixelOffsets = _mapPosition.getDisplayOffsets(getWidth(), getHeight());
-				for (int tileX = tileIndices[0]; tileX <= tileIndices[1] && !loadingFailed; tileX++)
+				for (int tileX = tileIndices[0]; tileX <= tileIndices[1]; tileX++)
 				{
 					int x = (tileX - tileIndices[0]) * 256 - pixelOffsets[0];
 					for (int tileY = tileIndices[2]; tileY <= tileIndices[3]; tileY++)
@@ -1539,7 +1552,7 @@ public class MapCanvas extends JPanel implements MouseListener, MouseMotionListe
 	}
 
 	/**
-	 * @param inE key released event, ignored
+	 * @param e key released event, ignored
 	 */
 	public void keyReleased(KeyEvent e)
 	{
