@@ -256,11 +256,9 @@ public class JpegLoader implements Runnable, Cancellable
 		if (timestamp == null) {
 			timestamp = new TimestampUtc(inFile.lastModified());
 		}
-		// Apply timestamp to photo and its point (if any)
+		// Apply timestamp to photo (but not its point)
 		photo.setTimestamp(timestamp);
-		if (photo.getDataPoint() != null) {
-			// photo.getDataPoint().setFieldValue(Field.TIMESTAMP, timestamp.getText(Timestamp.Format.ISO8601), false);
-		}
+
 		return photo;
 	}
 
